@@ -2,10 +2,11 @@ import logging
 import os
 import tempfile
 import warnings
+from collections.abc import Mapping, Sequence
 from configparser import ConfigParser
 from enum import Enum
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Mapping, Optional, Sequence, Type, Union
+from typing import TYPE_CHECKING, Any, Type
 
 from articat.utils.class_or_instance_method import class_or_instance_method
 
@@ -18,6 +19,7 @@ if TYPE_CHECKING:
 class ArticatMode(str, Enum):
     local = "local"
     gcp_datastore = "gcp_datastore"
+    test = "test"
 
 
 class ArticatConfig:
@@ -59,7 +61,7 @@ class ArticatConfig:
     @classmethod
     def register_config(
         cls,
-        config_paths: Optional[Sequence[str]] = None,
+        config_paths: Sequence[str] | None = None,
         config_dict: Mapping[str, Mapping[str, Any]] = {},
     ) -> "Type[ArticatConfig]":
         """
@@ -88,7 +90,7 @@ class ArticatConfig:
     @class_or_instance_method
     def mode(self) -> ArticatMode:
         """
-        Articat mode. Currently supported: `local`, `gcp`.
+        Articat mode. Currently supported: `local`, `gcp` and `test`.
         Defaults to: `local`
         """
         return ArticatMode(self._config.get("main", "mode", fallback=ArticatMode.local))
@@ -104,6 +106,10 @@ class ArticatConfig:
             from articat.catalog_datastore import CatalogDatastore
 
             return CatalogDatastore
+        elif self.mode() == ArticatMode.test:
+            from articat.tests.utils import TestCatalog
+
+            return TestCatalog
         else:
             raise ValueError(f"Unknown catalog for mode: {self.mode}")
 
@@ -190,9 +196,9 @@ class ArticatConfig:
 class ConfigMixin:
     """ArticatConfig mixin/trait"""
 
-    _config: Union[Type[ArticatConfig], ArticatConfig]
+    _config: type[ArticatConfig] | ArticatConfig
 
     @class_or_instance_method
-    def config(self) -> Union[Type[ArticatConfig], ArticatConfig]:
+    def config(self) -> type[ArticatConfig] | ArticatConfig:
         """Get Articat config object"""
         return self._config
